# Extensions

```{eval-rst}
.. module:: annsel.core.extensions
```

```{eval-rst}
.. currentmodule:: annsel
```

## Create an accessor

```{eval-rst}
.. autosummary::
    :toctree: ../generated

    register_anndata_accessor
```
